@@ -31,16 +31,16 @@ import time
 
 from xdg import BaseDirectory
 
+# Configuration and sound data paths
+from . import buildconfig
+
 # Locale/gettext configuration
 
 locale.setlocale(locale.LC_ALL, '')
-gettext.bindtextdomain ("speech-dispatcher", "/usr/local/share/locale")
-gettext.textdomain("speech-dispatcher")
+gettext.bindtextdomain (buildconfig.GETTEXT_PACKAGE, buildconfig.LOCALEDIR)
+gettext.textdomain(buildconfig.GETTEXT_PACKAGE)
 _ = gettext.gettext
 
-# Configuration and sound data paths
-from . import paths
-
 # two globals
 use_espeak_synthesis = False
 dont_ask = False
@@ -172,7 +172,7 @@ class Tests:
 
     def version(self):
         """Print version and copyright info"""
-        report("spd-conf 0.10.2\n")
+        report(f"spd-conf {buildconfig.VERSION}\n")
         report(_("""Copyright (C) %d-%d Brailcom, o.p.s.
 This is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by
@@ -186,7 +186,7 @@ any later version. Please see COPYING for more details.\n\n""") % \
 
     def system_conf_dir(self):
         """Determine system configuration directory"""
-        return paths.SPD_CONF_PATH
+        return buildconfig.SPD_CONF_PATH
 
     def user_conf_dir_exists(self):
         """Determine whether user configuration directory exists"""
@@ -244,7 +244,7 @@ Search for package like python-speechd, download and install it."""))
     def audio_try_play(self, type):
         """Try to play a sound through the standard playback utility for the
         given audio method."""
-        wavfile = os.path.join(paths.SPD_SOUND_DATA_PATH,"test.wav")
+        wavfile = os.path.join(buildconfig.SPD_SOUND_DATA_PATH,"test.wav")
 
         binary = None
 
@@ -613,7 +613,17 @@ Do you want to keep it?"""), False)
                     return
         # Copy the original intact configuration files
         # creating a conf/ subdirectory
-        shutil.copytree(paths.SPD_CONF_ORIG_PATH, self.test.user_conf_dir())
+        config_root = self.test.user_conf_dir()
+        shutil.copytree(buildconfig.SPD_CONF_ORIG_PATH, config_root)
+        # Ensure the files are writeable when copying from immutable directory.
+        umask = os.umask(0)
+        os.umask(umask)
+        os.chmod(self.test.user_conf_dir() , 0o755 & ~umask)
+        for root, dirs, files in os.walk(self.test.user_conf_dir()):
+            for d in dirs:
+                os.chmod(os.path.join(root, d), 0o755 & ~umask)
+            for f in files:
+                os.chmod(os.path.join(root, f), 0o644 & ~umask)
 
         report(_("User configuration created in %s" % self.test.user_conf_dir()))
 
@@ -678,8 +688,10 @@ Do you want to keep it?"""), False)
 This is usually not necessary, most applications will start Speech Dispatcher automatically."""),
                 False)
             if setup_autostart:
-                os.system("""cp %s ~/.config/autostart/""" % os.path.join(paths.SPD_DESKTOP_CONF_PATH,
-                                                                          "speechd.desktop"))
+                shutil.copy(
+                    os.path.join(buildconfig.SPD_DESKTOP_CONF_PATH, "speechd.desktop"),
+                    os.path.join(BaseDirectory.xdg_config_home, "autostart/")
+                )
 
                 report(_("""
 Configuration written to %s
@@ -777,8 +789,12 @@ you have to start it manually to continue."""))
 # Basic objects
 
 def main():
+    global dont_ask, use_espeak_synthesis
+
     options = setup_argparse()
     options = options.parse_args()
+    dont_ask = options.dont_ask
+    use_espeak_synthesis = options.use_espeak_synthesis
     test = Tests()
     configure = Configure(test) # that should possibly be refactored, test should not be passed
 
